# Reference

## Views

- [ListView](list_view.md) — display a list of model instances with tables and filters
- [DetailView](detail_view.md) — display a single model instance with property groups
- [CreateView](create_view.md) — create new model instances with forms
- [UpdateView](update_view.md) — update existing model instances with forms
- [DeleteView](delete_view.md) — delete model instances with confirmation
- [WorkflowView](workflow_view.md) — execute FSM state-machine transitions with audit history
- [PolymorphicView](polymorphic_view.md) — CRUD views for django-polymorphic models

## Configuration

- [Settings](settings.md) — all available settings for django-crud-views
